@@ -263,3 +263,7 @@ class SearchInfoExtractor(InfoExtractor):
     def _get_n_results(self, query, n):
         """Get a specified number of results for a query"""
         raise NotImplementedError("This method must be implemented by sublclasses")
+
+    @property
+    def SEARCH_KEY(self):
+        return self._SEARCH_KEY
